import React, { useState } from 'react';
import { Button } from '../components';
import { Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../components/tooltip';
import * as DropdownMenu from '@radix-ui/react-dropdown-menu';
import { Add, Close, Fullscreen, SettingsInputComponent } from '@mui/icons-material';
import ControlContainer from '../components/controls';
import { Visualizations } from './manager';

type Props = {
  manager: any;
};

export default function VisualizationBar({ manager }: Props) {
  const [visDropdownOpen, setVisDropdownOpen] = useState<boolean>(false);
  const [showVisSettings, setShowVisSettings] = useState<boolean>(false);

  const handleDragStart = (e: React.DragEvent<HTMLDivElement>, visId: string) => {
    e.dataTransfer.setData('text/plain', visId);
  };

  const handleDragOver = (e: React.DragEvent<HTMLDivElement>) => {
    e.preventDefault();
  };

  const handleDrop = (e: React.DragEvent<HTMLDivElement>, dropVisId: string) => {
    e.preventDefault();
    const draggedVisId = e.dataTransfer.getData('text/plain');
    manager.reorderVisualizations({ draggedVisId, dropVisId });
    manager.changeActive(draggedVisId);
  };

  return (
    <div>
      <div className="sticky top-0 flex items-center justify-between z-[2] py-0 px-2 bg-secondary-100 border-b border-secondary-200">
        <div className="flex divide-x">
          <div className="flex items-center">
            <h1 className="text-xs font-semibold text-secondary-600 mr-4">Visualization</h1>
          </div>
          <div className="flex justify-between w-full divide-x">
            {manager.tabs.map((visId: string) => {
              const isActive = manager.active === visId;
              return (
                <div
                  key={visId}
                  className={`flex items-center px-2 cursor-pointer border-seconday-200 border-b-2 -mb-[1px] ${isActive && 'border-b-primary-500'} ${!isActive && 'border-b-transparent hover:bg-secondary-200 transition-colors duration-150 ease-in-out'}`}
                  onClick={() => manager.changeActive(visId)}
                  onDragStart={(e) => handleDragStart(e, visId)}
                  onDragOver={(e) => handleDragOver(e)}
                  onDrop={(e) => handleDrop(e, visId)}
                  draggable
                >
                  <p className={`text-xs text-secondary-500 font-semibold mr-1 ${isActive && 'text-secondary-950'}`}>{visId}</p>
                  <Button
                    type="secondary"
                    variant="ghost"
                    rounded
                    size="2xs"
                    iconComponent={<Close />}
                    onClick={(e) => {
                      e.stopPropagation();
                      manager.deleteVisualization(visId);
                      if (manager.active === visId) {
                        const newActive = manager.tabs.find((v: string) => visId !== v);
                        manager.changeActive(newActive || '');
                      }
                    }}
                  />
                </div>
              );
            })}
          </div>
          <DropdownMenu.Root>
            <DropdownMenu.Trigger>
              <TooltipProvider delayDuration={0}>
                <Tooltip>
                  <TooltipTrigger>
                    <Button type="secondary" variant="ghost" size="xs" iconComponent={<Add />} onClick={() => {}} />
                  </TooltipTrigger>
                  <TooltipContent side={'bottom'} disabled={visDropdownOpen}>
                    <p>Add visualization</p>
                  </TooltipContent>
                </Tooltip>
              </TooltipProvider>
            </DropdownMenu.Trigger>
            <DropdownMenu.Portal>
              <DropdownMenu.Content className="bg-white p-1 rounded border">
                {Object.keys(Visualizations).map((key) => (
                  <DropdownMenu.Item
                    key={key}
                    className="text-sm px-2 py-1 rounded cursor-pointer hover:bg-secondary-200"
                    onClick={() => {
                      setVisDropdownOpen(false);
                      manager.changeActive(key);
                    }}
                  >
                    {key}
                  </DropdownMenu.Item>
                ))}
              </DropdownMenu.Content>
            </DropdownMenu.Portal>
          </DropdownMenu.Root>
        </div>
        <ControlContainer>
          <TooltipProvider delayDuration={0}>
            <Tooltip>
              <TooltipTrigger>
                <Button type="secondary" variant="ghost" size="xs" iconComponent={<Fullscreen />} onClick={() => {}} />
              </TooltipTrigger>
              <TooltipContent side={'bottom'}>
                <p>Full screen</p>
              </TooltipContent>
            </Tooltip>
          </TooltipProvider>
        </ControlContainer>
      </div>
    </div>
  );
}
